@@ -1,31 +1,13 @@
 package Catalyst::Plugin::Devel::ModuleVersions;
+our $VERSION = '0.100330';
+# ABSTRACT: Dump your loaded module versions to the debug-screen
+
 use strict;
 use warnings;
 
-use Class::C3;
+use MRO::Compat;
+use mro 'c3';
 
-our $VERSION = '0.0001';
-
-=head1 NAME
-
-Catalyst::Plugin::Devel::ModuleVersions - 
-
-=cut
-
-
-=head1 INTERFACE
-
-=head2 EXTENDED METHODS
-
-=head3 dump_these
-
-Uses Class::C3 to extend the catalyst dump_these, and add some more information
-at the end of the debug screen, containing a list of strings that each is
-"Module::Name VERSION", ala:
-
-    "Catalyst::Plugin::Devel::ModuleVersions 0.0001"
-
-=cut
 
 sub dump_these {
     my $c = shift; 
@@ -46,14 +28,44 @@ sub dump_these {
     ]); 
 }
 
-=head1 AUTHOR
-
-Andreas Marienborg C<<andremar@cpan.org>>
-
-=head1 LICENCE
-
-This library is free software, you can redistribute it and/or modify it
-under the same terms as Perl itself.
-
 
 1;
+
+
+
+__END__
+=pod
+
+=head1 NAME
+
+Catalyst::Plugin::Devel::ModuleVersions - Dump your loaded module versions to the debug-screen
+
+=head1 VERSION
+
+version 0.100330
+
+=head1 INTERFACE
+
+=head2 EXTENDED METHODS
+
+=head3 dump_these
+
+Uses Class::C3 to extend the catalyst dump_these, and add some more information
+at the end of the debug screen, containing a list of strings that each is
+"Module::Name VERSION", ala:
+
+    "Catalyst::Plugin::Devel::ModuleVersions 0.0001"
+
+=head1 AUTHOR
+
+  Andreas Marienborg <andremar@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2010 by Andreas Marienborg.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
+
